#!/usr/bin/env python3

import fileinput

for line in fileinput.input():
    if not line.startswith("LayoutName="):
        continue
    value = line[len("LayoutName="):].strip()
    if value != "coverswitch":
        continue
    print("# DELETE LayoutName") # will use the default layout



#!/usr/bin/env python3

import fileinput

def migrate_group(old, new, line):
    if not "[Effect-{}".format(old) in line:
        return
    print("# DELETE Effect-{}".format(old))
    print("[Effect-{}]\n".format(new))

for line in fileinput.input():
    if not "[Effect-" in line:
        print(line)
        continue
    migrate_group("Blur", "blur", line)
    migrate_group("DesktopGrid", "desktopgrid", line)
    migrate_group("DimInactive", "diminactive", line)
    migrate_group("FallApart", "fallapart", line)
    migrate_group("Glide", "glide", line)
    migrate_group("Kscreen", "kscreen", line)
    migrate_group("LookingGlass", "lookingglass", line)
    migrate_group("MagicLamp", "magiclamp", line)
    migrate_group("Magnifier", "magnifier", line)
    migrate_group("MouseClick", "mouseclick", line)
    migrate_group("MouseMark", "mousemark", line)
    migrate_group("Overview", "overview", line)
    migrate_group("PresentWindows", "presentwindows", line)
    migrate_group("Sheet", "sheet", line)
    migrate_group("ShowFps", "showfps", line)
    migrate_group("Slide", "slide", line)
    migrate_group("SlidingPopups", "slidingpopups", line)
    migrate_group("ThumbnailAside", "thumbnailaside", line)
    migrate_group("TrackMouse", "trackmouse", line)
    migrate_group("Wobbly", "wobblywindows", line)
    migrate_group("Zoom", "zoom", line)



#!/usr/bin/env python3

import fileinput

for line in fileinput.input():
    if not line.startswith("GLPreferBufferSwap="):
        continue
    value = line[len("GLPreferBufferSwap="):].strip()
    if value != "n":
        continue
    print("# DELETE GLPreferBufferSwap") # will use the default swap strategy



#!/usr/bin/env python3

import fileinput

for line in fileinput.input():
    if not line.startswith("Backend="):
        continue
    value = line[len("Backend="):].strip()
    if value != "XRender":
        continue
    print("# DELETE Backend") # will use the default compositing type



#!/usr/bin/env python3

import sys

VALUE_MAP = {
    'true': 0,
    'false': 1,
}

if __name__ == '__main__':
    for line in sys.stdin:
        line = line.strip()
        if line.startswith('PresentWindows='):
            _, value = line.split('=', 1)
            print("# DELETE PresentWindows")
            print("ClickBehavior=%d" % VALUE_MAP[value])



#!/usr/bin/env python3

import fileinput
import configparser
import os.path
import subprocess

# Get the config standard locations
config_locations = subprocess.check_output(['qtpaths', '--paths', 'ConfigLocation']).decode('utf-8').strip().split(':')
config_paths = [os.path.join(folder, 'kwinrc') for folder in config_locations]

# Get the desktops information from `kwinrc` config file
kwinrc = configparser.ConfigParser(strict=False, allow_no_value=True)
kwinrc.read(config_paths)

num_desktops = int(kwinrc.get('Desktops', 'Number', fallback=''))

# Generete the map from x11ids (ennumeration) to UUIDs
desktopUUIDs = { -1: "" } # NET::OnAllDesktops -> Empty string
for i in range(1, num_desktops + 1):
    uuid = kwinrc.get('Desktops', f'Id_{i}', fallback='')
    desktopUUIDs[i] = str(uuid)

# Apply the conversion to `kwinrulesrc`
for line in fileinput.input():
    # Rename key `desktoprule` to `desktopsrule`
    if line.startswith("desktoprule="):
        value = line[len("desktoprule="):].strip()
        print("desktopsrule=" + value)
        print("# DELETE desktoprule")
        continue

    if not line.startswith("desktop="):
        print(line.strip())
        continue

    # Convert key `desktop` (x11id) to `desktops` (list of UUIDs)
    try:
        value = line[len("desktop="):].strip()
        x11id = int(value)
        uuid = desktopUUIDs[x11id]
    except:
        print(line.strip())  # If there is some error, print back the line
        continue

    print("desktops=" + uuid)
    print("# DELETE desktop")



#!/usr/bin/env python3

import fileinput

for line in fileinput.input():
    if not line.startswith("cubeslideEnabled="):
        continue
    value = line[len("cubeslideEnabled="):].strip()
    if value == "true":
        print("# DELETE cubeslideEnabled")
        print("# DELETE slideEnabled") # make slide effect enabled, it's off now
